@@ -1,7 +1,6 @@
 ## ----warning=FALSE,message=FALSE----------------------------------------------
 knit_by_pkgdown <- !is.null(knitr::opts_chunk$get("fig.retina"))
 knitr::opts_chunk$set(warning = FALSE, message = TRUE, error = FALSE)
-pander::panderOptions("table.split.table", Inf)
 ggplot2::theme_set(ggplot2::theme_bw())
 
 library(codebook)
@@ -50,9 +49,9 @@ meta <- recursive_escape(meta)
 
 ## ----results='asis'-----------------------------------------------------------
 if (exists("name", meta)) {
-  glue::glue(
+  glue::glue_data(
     "__Dataset name__: {name}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis'-----------------------------------------------------------
@@ -60,30 +59,30 @@ cat(description)
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("temporalCoverage", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __Temporal Coverage__: {temporalCoverage}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("spatialCoverage", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __Spatial Coverage__: {spatialCoverage}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("citation", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __Citation__: {citation}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("url", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __URL__: [{url}]({url})",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
@@ -93,22 +92,22 @@ if (exists("identifier", meta)) {
       stringr::str_match(meta$identifier, "^doi:(.+)")[,2], '">', 
       meta$identifier, '</a>')
   }
-  glue::glue(
+  glue::glue_data(
     "- __Identifier__: {identifier}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("datePublished", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __Date published__: {datePublished}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("creator", meta)) {
   cat("- __Creator__:")
-  pander::pander(meta$creator)
+  knitr::kable(tibble::enframe(meta$creator))
 }
 
 ## -----------------------------------------------------------------------------
@@ -116,7 +115,9 @@ meta <- meta[setdiff(names(meta),
                      c("creator", "datePublished", "identifier",
                        "url", "citation", "spatialCoverage", 
                        "temporalCoverage", "description", "name"))]
-pander::pander(meta)
+if(length(meta)) {
+  knitr::kable(meta)
+}
 
 ## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (exists("testing")) {
@@ -126,7 +127,7 @@ if (exists("testing")) {
 	reliabilities = list()
 }
 
-## ----repeated-----------------------------------------------------------------
+## ----repeated,fig.cap="Number of sessions"------------------------------------
 if (survey_repetition != "single") {
 	overview = results %>% dplyr::group_by(session) %>% 
 		dplyr::summarise(
@@ -143,14 +144,11 @@ if (survey_repetition != "single") {
 	)
 }
 
-## ----starting_time------------------------------------------------------------
+## ----starting_time,fig.cap="Starting date times"------------------------------
 ggplot2::qplot(results$created) + ggplot2::scale_x_datetime("Date/time when survey was started")
 
-## ----duration-----------------------------------------------------------------
-if (low_vals == 0) {
-  warning("Durations below 0 detected.")
-}
-ggplot2::qplot(duration$duration, binwidth = 0.5) + ggplot2::scale_x_continuous(paste("Duration (in minutes), excluding", high_vals, "values above median + 4*MAD"), limits = c(lower_limit, upper_limit))
+## ----duration,fig.cap="Duration people took for answering the survey"---------
+ggplot2::qplot(duration$duration, binwidth = 0.5) + ggplot2::scale_x_continuous(paste("Duration (in minutes), excluding", high_vals, "values above median + 4*MAD and ", low_vals, "values below 0."), limits = c(lower_limit, upper_limit))
 
 ## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (!exists("indent")) {
@@ -174,21 +172,17 @@ new_height <- ifelse(new_height > 20, 20, new_height)
 new_height <- ifelse(new_height < 1, 1, new_height)
 new_height <- ifelse(is.na(new_height) | is.nan(new_height), 
                      old_height, new_height)
-knitr::opts_chunk$set(fig.height = new_height)
 
-## ----likert-------------------------------------------------------------------
+## ----likert,fig.height=new_height,fig.cap=paste("Likert plot of scale", html_scale_name, "items")----
 if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
   likert_plot <- likert_from_items(items)
   if (!is.null(likert_plot)) {
     graphics::plot(likert_plot)
   }
 }
-knitr::opts_chunk$set(fig.height = old_height)
 
-## ----setup_distribution-------------------------------------------------------
+## ----distribution,fig.cap=paste("Distribution of scale", html_scale_name)-----
 wrap_at <- knitr::opts_chunk$get("fig.width") * 10
-
-## ----distribution-------------------------------------------------------------
 dist_plot <- plot_labelled(scale, scale_name, wrap_at)
 
 choices <- attributes(items[[1]])$item$choices
@@ -210,53 +204,38 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
-  x = userfriendlyscience::scaleDiagnosis(testDat, 
-                                          scaleReliability.ci = FALSE)
-	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
-  x = userfriendlyscience::scaleDiagnosis(testDat, 
-                                          scaleReliability.ci = TRUE)
+	example("alpha", "psych")
+  x = a4
 }
 
 ## -----------------------------------------------------------------------------
-coefs <- x$scaleReliability$output$dat %>% 
-  tidyr::gather(index, estimate) %>% 
-  dplyr::filter(index != "n.items", index != "n.observations") %>% 
-  dplyr::mutate(index = stringr::str_to_title(
-    stringr::str_replace_all(index,
-      stringr::fixed("."), " ")))
-
-cis <- coefs %>% 
-  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
-  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
-  tidyr::spread(hilo, estimate)
-if (nrow(cis)) {
-  cis <- cis %>% dplyr::rename(
-    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
-  )
+if (!is.null(x$total$ase)) {
+  knitr::kable(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
+             estimate = x$total$raw_alpha, 
+             upper = x$total$raw_alpha + 1.96 * 
+  x$total$ase))
 }
 
-coefs_with_cis <- coefs %>% 
-  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
-    dplyr::left_join(cis, by = "index") %>% 
-    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
-    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
-    dplyr::select(Index = .data$index, Estimate = .data$estimate)
-
-
-pander::pander(coefs_with_cis)
+## -----------------------------------------------------------------------------
+knitr::kable(x$total)
 
 ## -----------------------------------------------------------------------------
-print(x$scatterMatrix$output$scatterMatrix)
-x$scatterMatrix$output$scatterMatrix <- no_md()
+rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
+knitr::kable(x$alpha.drop)
 
 ## -----------------------------------------------------------------------------
-print(x)
+rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
+knitr::kable(x$item.stats)
+
+## -----------------------------------------------------------------------------
+rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
+knitr::kable(x$response.freq)
 
 ## ----reliability, results='asis'----------------------------------------------
 for (i in seq_along(reliabilities)) {
   rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
+  suppressMessages(rel_output <- knitr::knit_print(rel))
+  cat(rel_output)
 }
 
 ## ----summary------------------------------------------------------------------
@@ -287,21 +266,17 @@ new_height <- ifelse(new_height > 20, 20, new_height)
 new_height <- ifelse(new_height < 1, 1, new_height)
 new_height <- ifelse(is.na(new_height) | is.nan(new_height), 
                      old_height, new_height)
-knitr::opts_chunk$set(fig.height = new_height)
 
-## ----likert-------------------------------------------------------------------
+## ----likert,fig.height=new_height,fig.cap=paste("Likert plot of scale", html_scale_name, "items")----
 if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
   likert_plot <- likert_from_items(items)
   if (!is.null(likert_plot)) {
     graphics::plot(likert_plot)
   }
 }
-knitr::opts_chunk$set(fig.height = old_height)
 
-## ----setup_distribution-------------------------------------------------------
+## ----distribution,fig.cap=paste("Distribution of scale", html_scale_name)-----
 wrap_at <- knitr::opts_chunk$get("fig.width") * 10
-
-## ----distribution-------------------------------------------------------------
 dist_plot <- plot_labelled(scale, scale_name, wrap_at)
 
 choices <- attributes(items[[1]])$item$choices
@@ -323,53 +298,38 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
-  x = userfriendlyscience::scaleDiagnosis(testDat, 
-                                          scaleReliability.ci = FALSE)
-	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
-  x = userfriendlyscience::scaleDiagnosis(testDat, 
-                                          scaleReliability.ci = TRUE)
+	example("alpha", "psych")
+  x = a4
 }
 
 ## -----------------------------------------------------------------------------
-coefs <- x$scaleReliability$output$dat %>% 
-  tidyr::gather(index, estimate) %>% 
-  dplyr::filter(index != "n.items", index != "n.observations") %>% 
-  dplyr::mutate(index = stringr::str_to_title(
-    stringr::str_replace_all(index,
-      stringr::fixed("."), " ")))
-
-cis <- coefs %>% 
-  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
-  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
-  tidyr::spread(hilo, estimate)
-if (nrow(cis)) {
-  cis <- cis %>% dplyr::rename(
-    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
-  )
+if (!is.null(x$total$ase)) {
+  knitr::kable(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
+             estimate = x$total$raw_alpha, 
+             upper = x$total$raw_alpha + 1.96 * 
+  x$total$ase))
 }
 
-coefs_with_cis <- coefs %>% 
-  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
-    dplyr::left_join(cis, by = "index") %>% 
-    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
-    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
-    dplyr::select(Index = .data$index, Estimate = .data$estimate)
-
-
-pander::pander(coefs_with_cis)
+## -----------------------------------------------------------------------------
+knitr::kable(x$total)
 
 ## -----------------------------------------------------------------------------
-print(x$scatterMatrix$output$scatterMatrix)
-x$scatterMatrix$output$scatterMatrix <- no_md()
+rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
+knitr::kable(x$alpha.drop)
 
 ## -----------------------------------------------------------------------------
-print(x)
+rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
+knitr::kable(x$item.stats)
+
+## -----------------------------------------------------------------------------
+rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
+knitr::kable(x$response.freq)
 
 ## ----reliability, results='asis'----------------------------------------------
 for (i in seq_along(reliabilities)) {
   rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
+  suppressMessages(rel_output <- knitr::knit_print(rel))
+  cat(rel_output)
 }
 
 ## ----summary------------------------------------------------------------------
@@ -428,7 +388,7 @@ if (
 }
 attributes(item_nomiss) <- attributes(item)
 
-old_height <- knitr::opts_chunk$get("fig.height")
+fig_height_dist <- knitr::opts_chunk$get("fig.height")
 non_missing_choices <- item_attributes[["labels"]]
 many_labels <- length(non_missing_choices) > 7
 go_vertical <- !is_numeric_or_time_var(item_nomiss) || many_labels
@@ -442,19 +402,17 @@ if ( go_vertical ) {
 		non_missing_choices <- unique(item_nomiss)
 		names(non_missing_choices) <- non_missing_choices
 	}
-  choice_multiplier <- old_height/6.5
-	new_height <- 2 + choice_multiplier * length(non_missing_choices)
-	new_height <- ifelse(new_height > 20, 20, new_height)
-	new_height <- ifelse(new_height < 1, 1, new_height)
-	if(could_disclose_unique_values(item_nomiss) && is.character(item_nomiss)) {
-	  new_height <- old_height
-	}
-	knitr::opts_chunk$set(fig.height = new_height)
+  if(!(could_disclose_unique_values(item_nomiss) && is.character(item_nomiss))) {
+    choice_multiplier <- fig_height_dist/6.5
+  	fig_height_dist <- 2 + choice_multiplier * length(non_missing_choices)
+  	fig_height_dist <- ifelse(fig_height_dist > 20, 20, fig_height_dist)
+  	fig_height_dist <- ifelse(fig_height_dist < 1, 1, fig_height_dist)
+  }
 }
 
-wrap_at <- knitr::opts_chunk$get("fig.width") * 10
 
-## ----distribution-------------------------------------------------------------
+## ----distribution,fig.height=fig_height_dist,fig.cap=paste("Distribution of values for", html_item_name)----
+wrap_at <- knitr::opts_chunk$get("fig.width") * 10
 # todo: if there are free-text choices mingled in with the pre-defined ones, don't show
 # todo: show rare items if they are pre-defined
 # todo: bin rare responses into "other category"
@@ -472,15 +430,18 @@ if (!length(item_nomiss)) {
 	  cat(dplyr::n_distinct(item_nomiss), " unique, categorical values, so not shown.")
   }
 }
-knitr::opts_chunk$set(fig.height = old_height)
 
 ## ----summary------------------------------------------------------------------
 attributes(item) <- item_attributes
 df = data.frame(item, stringsAsFactors = FALSE)
 names(df) = html_item_name
-escaped_table(codebook_table(df))
+cb_table <- codebook_table(df)
+if(!is.null(choices)) {
+  cb_table$value_labels <- NULL
+}
+escaped_table(cb_table)
 
-## ----missing_values-----------------------------------------------------------
+## ----missing_values,fig.cap=paste("Plot of missing values for", html_item_name)----
 if (show_missing_values) {
   plot_labelled(missing_values, item_name, wrap_at)
 }
@@ -488,19 +449,19 @@ if (show_missing_values) {
 ## ----item_info----------------------------------------------------------------
 if (!is.null(item_info)) {
   # don't show choices again, if they're basically same thing as value labels
-  if (!is.null(choices) && !is.null(item_info$choices) && 
-    all(names(na.omit(choices)) == item_info$choices) &&
-    all(na.omit(choices) == names(item_info$choices))) {
-    item_info$choices <- NULL
+  if (is.null(choices)) {
+    choices <- tibble::enframe(item_info$choices)
   }
+  item_info$choices <- NULL
   item_info$label_parsed <- 
     item_info$choice_list <- item_info$study_id <- item_info$id <- NULL
-  pander::pander(item_info)
+  knitr::kable(purrr::flatten_df(item_info), caption = "Item options")
 }
 
 ## ----choices------------------------------------------------------------------
 if (!is.null(choices) && length(choices) && length(choices) < 30) {
-	pander::pander(as.list(choices))
+  try({choices <- tibble::enframe(choices)}, silent = TRUE)
+  knitr::kable(choices, caption = "Response choices")
 }
 
 ## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
@@ -516,7 +477,7 @@ if (exists("testing")) {
 
 ## ----missingness_all_setup----------------------------------------------------
 if (length(md_pattern)) {
-  if (knitr::is_html_output()) {
+  if (knitr::is_html_output() && requireNamespace("rmarkdown", quietly = TRUE)) {
     rmarkdown::paged_table(md_pattern, options = list(rows.print = 10))
   } else {
     knitr::kable(md_pattern)
@@ -525,11 +486,10 @@ if (length(md_pattern)) {
 
 ## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (exists("testing")) {
-	indent = '#' # ugly hack so _regression_summary can be "spun" (variables included via `r ` have to be available)
+	indent = '#' # ugly hack so _metadata_jsonld.Rmd can be "spun" (variables included via `r ` have to be available)
 	results = data.frame()
-	jsonld_metadata <- list(test = 1)
+	jsonld_metadata <- jsonlite::toJSON(list(test = 1), pretty = TRUE, auto_unbox = TRUE)
 }
-json <- jsonlite::toJSON(jsonld_metadata, pretty = TRUE, auto_unbox = TRUE)
 
 ## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
 if (!exists("indent")) {
